@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified September 28, 2018
+Last modified October 10, 2018
 
 Description:  Merges .pgm files.
 
@@ -12,6 +12,11 @@ Usage:  mergepgm.sh in=x.pgm,y.pgm out=z.pgm
 File parameters:
 in=<file,file>  A pgm file or comma-delimited list of pgm files.
 out=<file>      Output filename.
+normalize=f     Merge proportionally to base counts, so small models
+                have equal weight to large models.  Normalization happens
+                before applying the @ multiplier.
+@ symbol        Input filenames in the form of 'x.pgm@0.1' will have
+                a multiplier applied to that model prior to merging.
 
 Please contact Brian Bushnell at bbushnell@lbl.gov if you encounter any problems.
 "
